@@ -47,6 +47,12 @@ class PHYSICS_UL_dynapaint_surfaces(bpy_types.UIList, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -208,6 +214,12 @@ class PHYSICS_PT_dp_advanced_canvas(PhysicButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -358,6 +370,12 @@ class PHYSICS_PT_dp_brush_source(PhysicButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -511,6 +529,12 @@ class PHYSICS_PT_dp_brush_velocity(PhysicButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -664,6 +688,12 @@ class PHYSICS_PT_dp_brush_wave(PhysicButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -817,6 +847,12 @@ class PHYSICS_PT_dp_cache(PhysicButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -970,6 +1006,12 @@ class PHYSICS_PT_dp_canvas_initial_color(PhysicButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1123,6 +1165,12 @@ class PHYSICS_PT_dp_canvas_output(PhysicButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1276,6 +1324,12 @@ class PHYSICS_PT_dp_effects(PhysicButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1426,6 +1480,12 @@ class PHYSICS_PT_dynamic_paint(PhysicButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1515,19 +1575,3 @@ class PHYSICS_PT_dynamic_paint(PhysicButtonsPanel, bpy_types.Panel,
 
         '''
         pass
-
-
-def register():
-    ''' 
-
-    '''
-
-    pass
-
-
-def unregister():
-    ''' 
-
-    '''
-
-    pass
