@@ -1,10 +1,10 @@
 import sys
 import typing
-from . import translations
 from . import handlers
+from . import translations
 
 alembic = None
-''' constant value bpy.app.alembic(supported=True, version=(1, 6, 0), version_string=' 1, 6, 0')
+''' constant value bpy.app.alembic(supported=True, version=(1, 7, 1), version_string=' 1, 7, 1')
 '''
 
 autoexec_fail = None
@@ -68,7 +68,7 @@ build_linkflags = None
 '''
 
 build_options = None
-''' constant value bpy.app.build_options(bullet=True, codec_avi=True, codec_ffmpeg=True, codec_quicktime=False, codec_sndfile=False, compositor=True, cycles=True, cycles_osl=True, freestyle=True, gameengine=True, image_cineon=True, image_dds=True, image_frameserver=True, image_hdr=True, image_openexr=True, image_openjpeg=True, image_tiff=True, input_ndof=True, audaspace=True, international=True, openal=True, sdl=True, sdl_dynload=True, jack=True, libmv=True, mod_boolean=True, mod_fluid=True, mod_oceansim=True, ...)
+''' constant value bpy.app.build_options(bullet=True, codec_avi=True, codec_ffmpeg=True, codec_quicktime=False, codec_sndfile=True, compositor=True, cycles=True, cycles_osl=True, freestyle=True, gameengine=True, image_cineon=True, image_dds=True, image_frameserver=True, image_hdr=True, image_openexr=True, image_openjpeg=True, image_tiff=True, input_ndof=True, audaspace=True, international=True, openal=True, sdl=True, sdl_dynload=True, jack=True, libmv=True, mod_boolean=True, mod_fluid=True, mod_oceansim=True, ...)
 '''
 
 build_platform = None
@@ -135,12 +135,16 @@ driver_namespace = None
 ''' Dictionary for drivers namespace, editable in-place, reset on file load (read-only)
 '''
 
+factory_startup = None
+''' Boolean, True when blender is running with --factory-startup)
+'''
+
 ffmpeg = None
 ''' constant value bpy.app.ffmpeg(supported=True, avcodec_version=(57, 64, 101), avcodec_version_string='57, 64, 101', avdevice_version=(57, 1, 100), avdevice_version_string='57, 1, 100', avformat_version=(57, 56, 100), avformat_version_string='57, 56, 100', avutil_version=(55, 34, 100), avutil_version_string='55, 34, 100', swscale_version=(4, 2, 100), swscale_version_string=' 4, 2, 100')
 '''
 
 handlers = None
-''' constant value bpy.app.handlers(frame_change_pre=[], frame_change_post=[], render_pre=[], render_post=[], render_write=[], render_stats=[], render_init=[], render_complete=[], render_cancel=[], load_pre=[], load_post=[], save_pre=[], save_post=[], scene_update_pre=[], scene_update_post=[], game_pre=[], game_post=[], version_update=[<function do_versions at 0x7f62a8aa72f0>], persistent=<class 'persistent'>)
+''' constant value bpy.app.handlers(frame_change_pre=[], frame_change_post=[], render_pre=[], render_post=[], render_write=[], render_stats=[], render_init=[], render_complete=[], render_cancel=[], load_pre=[], load_post=[], save_pre=[], save_post=[], scene_update_pre=[], scene_update_post=[], game_pre=[], game_post=[], version_update=[<function do_versions at 0x7fe6b67f40d0>], persistent=<class 'persistent'>)
 '''
 
 ocio = None
@@ -148,7 +152,11 @@ ocio = None
 '''
 
 oiio = None
-''' constant value bpy.app.oiio(supported=True, version=(1, 7, 8), version_string=' 1, 7, 8')
+''' constant value bpy.app.oiio(supported=True, version=(1, 7, 15), version_string=' 1, 7, 15')
+'''
+
+opensubdiv = None
+''' constant value bpy.app.opensubdiv(supported=True, version=(3, 1, 1), version_string=' 3, 1, 1')
 '''
 
 openvdb = None
