@@ -65,11 +65,11 @@ save_pre = None
 '''
 
 scene_update_post = None
-''' on updating the scenes data (after)
+''' on every scene data update. Does not imply that anything changed in the scene, just that the dependency graph was reevaluated, and the scene was possibly updated by Blender's animation system.
 '''
 
 scene_update_pre = None
-''' on updating the scenes data (before)
+''' on every scene data update. Does not imply that anything changed in the scene, just that the dependency graph is about to be reevaluated, and the scene is about to be updated by Blender's animation system.
 '''
 
 version_update = None
