@@ -52,7 +52,7 @@ def apply_solution_scale(distance: float = 0.0):
 
 
 def bundles_to_mesh():
-    ''' Create vertex cloud using coordinates of reconstructed tracks :file: startup/bl_operators/clip.py <https://developer.blender.org/diffusion/B/browse/master/release/scripts/ /startup/bl_operators/clip.py> _:278
+    ''' Create vertex cloud using coordinates of reconstructed tracks
 
     '''
 
@@ -123,7 +123,7 @@ def clear_track_path(action: typing.Union[str, int] = 'REMAINED',
 
 
 def constraint_to_fcurve():
-    ''' Create F-Curves for object which will copy object's movement caused by this constraint :file: startup/bl_operators/clip.py <https://developer.blender.org/diffusion/B/browse/master/release/scripts/ /startup/bl_operators/clip.py> _:504
+    ''' Create F-Curves for object which will copy object's movement caused by this constraint
 
     '''
 
@@ -165,7 +165,7 @@ def delete_marker():
 
 
 def delete_proxy():
-    ''' Delete movie clip proxy files from the hard drive :file: startup/bl_operators/clip.py <https://developer.blender.org/diffusion/B/browse/master/release/scripts/ /startup/bl_operators/clip.py> _:347
+    ''' Delete movie clip proxy files from the hard drive
 
     '''
 
@@ -403,10 +403,8 @@ def mode_set(mode: typing.Union[str, int] = 'TRACKING'):
 
 
 def open(directory: str = "",
-         files: typing.
-         Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.
-               List['bpy.types.OperatorFileListElement'],
-               'bpy_prop_collection'] = None,
+         files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
+                             'bpy_prop_collection'] = None,
          filter_blender: bool = False,
          filter_backup: bool = False,
          filter_image: bool = True,
@@ -431,7 +429,7 @@ def open(directory: str = "",
     :param directory: Directory, Directory of the file
     :type directory: str
     :param files: Files
-    :type files: typing.Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
+    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param filter_blender: Filter .blend files
     :type filter_blender: bool
     :param filter_backup: Filter .blend files
@@ -601,15 +599,14 @@ def select_grouped(group: typing.Union[str, int] = 'ESTIMATED'):
     pass
 
 
-def select_lasso(path: typing.Union[
-        typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.
-        List['bpy.types.OperatorMousePath'], 'bpy_prop_collection'] = None,
+def select_lasso(path: typing.Union[typing.List['bpy.types.OperatorMousePath'],
+                                    'bpy_prop_collection'] = None,
                  deselect: bool = False,
                  extend: bool = True):
     ''' Select markers using lasso selection
 
     :param path: Path
-    :type path: typing.Union[typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
+    :type path: typing.Union[typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
     :param deselect: Deselect, Deselect rather than select items
     :type deselect: bool
     :param extend: Extend, Extend selection instead of deselecting everything first
@@ -620,7 +617,7 @@ def select_lasso(path: typing.Union[
 
 
 def set_active_clip():
-    ''' Undocumented :file: startup/bl_operators/clip.py <https://developer.blender.org/diffusion/B/browse/master/release/scripts/ /startup/bl_operators/clip.py> _:212
+    ''' Undocumented
 
     '''
 
@@ -704,7 +701,7 @@ def set_solver_keyframe(keyframe: typing.Union[str, int] = 'KEYFRAME_A'):
 
 
 def set_viewport_background():
-    ''' Set current movie clip as a camera background in 3D view-port (works only when a 3D view-port is visible) :file: startup/bl_operators/clip.py <https://developer.blender.org/diffusion/B/browse/master/release/scripts/ /startup/bl_operators/clip.py> _:408
+    ''' Set current movie clip as a camera background in 3D view-port (works only when a 3D view-port is visible)
 
     '''
 
@@ -712,7 +709,7 @@ def set_viewport_background():
 
 
 def setup_tracking_scene():
-    ''' Prepare scene for compositing 3D objects into this footage :file: startup/bl_operators/clip.py <https://developer.blender.org/diffusion/B/browse/master/release/scripts/ /startup/bl_operators/clip.py> _:972
+    ''' Prepare scene for compositing 3D objects into this footage
 
     '''
 
@@ -834,7 +831,7 @@ def track_markers(backwards: bool = False, sequence: bool = False):
 
 
 def track_settings_as_default():
-    ''' Copy tracking settings from active track to default settings :file: startup/bl_operators/clip.py <https://developer.blender.org/diffusion/B/browse/master/release/scripts/ /startup/bl_operators/clip.py> _:1009
+    ''' Copy tracking settings from active track to default settings
 
     '''
 
@@ -842,7 +839,7 @@ def track_settings_as_default():
 
 
 def track_settings_to_track():
-    ''' Copy tracking settings from active track to selected tracks :file: startup/bl_operators/clip.py <https://developer.blender.org/diffusion/B/browse/master/release/scripts/ /startup/bl_operators/clip.py> _:1057
+    ''' Copy tracking settings from active track to selected tracks
 
     '''
 
@@ -850,7 +847,7 @@ def track_settings_to_track():
 
 
 def track_to_empty():
-    ''' Create an Empty object which will be copying movement of active track :file: startup/bl_operators/clip.py <https://developer.blender.org/diffusion/B/browse/master/release/scripts/ /startup/bl_operators/clip.py> _:254
+    ''' Create an Empty object which will be copying movement of active track
 
     '''
 
