@@ -21,11 +21,11 @@ def clear_render_border():
     pass
 
 
-def curves_point_set(point: typing.Union[int, str] = 'BLACK_POINT'):
+def curves_point_set(point: typing.Union[str, int] = 'BLACK_POINT'):
     ''' Set black point or white point for curves
 
     :param point: Point, Set black point or white point for curves
-    :type point: typing.Union[int, str]
+    :type point: typing.Union[str, int]
     '''
 
     pass
@@ -83,13 +83,13 @@ def new(name: str = "Untitled",
         height: int = 1024,
         color: typing.List[float] = (0.0, 0.0, 0.0, 1.0),
         alpha: bool = True,
-        generated_type: typing.Union[int, str] = 'BLANK',
+        generated_type: typing.Union[str, int] = 'BLANK',
         float: bool = False,
-        gen_context: typing.Union[int, str] = 'NONE',
+        gen_context: typing.Union[str, int] = 'NONE',
         use_stereo_3d: bool = False):
     ''' Create a new image
 
-    :param name: Name, Image datablock name
+    :param name: Name, Image data-block name
     :type name: str
     :param width: Width, Image width
     :type width: int
@@ -100,11 +100,11 @@ def new(name: str = "Untitled",
     :param alpha: Alpha, Create an image with an alpha channel
     :type alpha: bool
     :param generated_type: Generated Type, Fill the image with a grid for UV map testing * BLANK Blank, Generate a blank image. * UV_GRID UV Grid, Generated grid to test UV mappings. * COLOR_GRID Color Grid, Generated improved UV grid to test UV mappings.
-    :type generated_type: typing.Union[int, str]
+    :type generated_type: typing.Union[str, int]
     :param float: 32 bit Float, Create image with 32 bit floating point bit depth
     :type float: bool
     :param gen_context: Gen Context, Generation context
-    :type gen_context: typing.Union[int, str]
+    :type gen_context: typing.Union[str, int]
     :param use_stereo_3d: Stereo 3D, Create an image with left and right views
     :type use_stereo_3d: bool
     '''
@@ -114,10 +114,8 @@ def new(name: str = "Untitled",
 
 def open(filepath: str = "",
          directory: str = "",
-         files: typing.
-         Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.
-               List['bpy.types.OperatorFileListElement'],
-               'bpy_prop_collection'] = None,
+         files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
+                             'bpy_prop_collection'] = None,
          filter_blender: bool = False,
          filter_backup: bool = False,
          filter_image: bool = True,
@@ -135,8 +133,9 @@ def open(filepath: str = "",
          relative_path: bool = True,
          show_multiview: bool = False,
          use_multiview: bool = False,
-         display_type: typing.Union[int, str] = 'DEFAULT',
-         sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA'):
+         display_type: typing.Union[str, int] = 'DEFAULT',
+         sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA',
+         use_sequence_detection: bool = True):
     ''' Open image
 
     :param filepath: File Path, Path to file
@@ -144,7 +143,7 @@ def open(filepath: str = "",
     :param directory: Directory, Directory of the file
     :type directory: str
     :param files: Files
-    :type files: typing.Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
+    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param filter_blender: Filter .blend files
     :type filter_blender: bool
     :param filter_backup: Filter .blend files
@@ -180,9 +179,11 @@ def open(filepath: str = "",
     :param use_multiview: Use Multi-View
     :type use_multiview: bool
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_SHORT Short List, Display files as short list. * LIST_LONG Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[int, str]
+    :type display_type: typing.Union[str, int]
     :param sort_method: File sorting mode * FILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically. * FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type. * FILE_SORT_TIME Sort by time, Sort files by modification time. * FILE_SORT_SIZE Sort by size, Sort files by size.
-    :type sort_method: typing.Union[int, str]
+    :type sort_method: typing.Union[str, int]
+    :param use_sequence_detection: Detect Sequences, Automatically detect animated sequences in selected images (based on file names)
+    :type use_sequence_detection: bool
     '''
 
     pass
@@ -199,7 +200,7 @@ def pack(as_png: bool = False):
 
 
 def project_apply():
-    ''' Project edited image back onto the object :file: startup/bl_operators/image.py <https://developer.blender.org/diffusion/B/browse/master/release/scripts/ /startup/bl_operators/image.py> _:230
+    ''' Project edited image back onto the object
 
     '''
 
@@ -207,7 +208,7 @@ def project_apply():
 
 
 def project_edit():
-    ''' Edit a snapshot of the view-port in an external image editor :file: startup/bl_operators/image.py <https://developer.blender.org/diffusion/B/browse/master/release/scripts/ /startup/bl_operators/image.py> _:159
+    ''' Edit a snapshot of the view-port in an external image editor
 
     '''
 
@@ -272,8 +273,8 @@ def replace(filepath: str = "",
             relative_path: bool = True,
             show_multiview: bool = False,
             use_multiview: bool = False,
-            display_type: typing.Union[int, str] = 'DEFAULT',
-            sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA'):
+            display_type: typing.Union[str, int] = 'DEFAULT',
+            sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA'):
     ''' Replace current image by another one from disk
 
     :param filepath: File Path, Path to file
@@ -313,9 +314,9 @@ def replace(filepath: str = "",
     :param use_multiview: Use Multi-View
     :type use_multiview: bool
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_SHORT Short List, Display files as short list. * LIST_LONG Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[int, str]
+    :type display_type: typing.Union[str, int]
     :param sort_method: File sorting mode * FILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically. * FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type. * FILE_SORT_TIME Sort by time, Sort files by modification time. * FILE_SORT_SIZE Sort by size, Sort files by size.
-    :type sort_method: typing.Union[int, str]
+    :type sort_method: typing.Union[str, int]
     '''
 
     pass
@@ -380,8 +381,8 @@ def save_as(save_as_render: bool = False,
             relative_path: bool = True,
             show_multiview: bool = False,
             use_multiview: bool = False,
-            display_type: typing.Union[int, str] = 'DEFAULT',
-            sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA'):
+            display_type: typing.Union[str, int] = 'DEFAULT',
+            sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA'):
     ''' Save the image with another name and/or settings
 
     :param save_as_render: Save As Render, Apply render part of display transform when saving byte image
@@ -427,16 +428,16 @@ def save_as(save_as_render: bool = False,
     :param use_multiview: Use Multi-View
     :type use_multiview: bool
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_SHORT Short List, Display files as short list. * LIST_LONG Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[int, str]
+    :type display_type: typing.Union[str, int]
     :param sort_method: File sorting mode * FILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically. * FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type. * FILE_SORT_TIME Sort by time, Sort files by modification time. * FILE_SORT_SIZE Sort by size, Sort files by size.
-    :type sort_method: typing.Union[int, str]
+    :type sort_method: typing.Union[str, int]
     '''
 
     pass
 
 
 def save_dirty():
-    ''' Save all modified textures :file: startup/bl_operators/image.py <https://developer.blender.org/diffusion/B/browse/master/release/scripts/ /startup/bl_operators/image.py> _:124
+    ''' Save all modified textures
 
     '''
 
@@ -459,12 +460,12 @@ def toolshelf():
     pass
 
 
-def unpack(method: typing.Union[int, str] = 'USE_LOCAL', id: str = ""):
+def unpack(method: typing.Union[str, int] = 'USE_LOCAL', id: str = ""):
     ''' Save an image packed in the .blend file to disk
 
     :param method: Method, How to unpack
-    :type method: typing.Union[int, str]
-    :param id: Image Name, Image datablock name to unpack
+    :type method: typing.Union[str, int]
+    :param id: Image Name, Image data-block name to unpack
     :type id: str
     '''
 
