@@ -94,11 +94,11 @@ def feather_weight_clear():
     pass
 
 
-def handle_type_set(type: typing.Union[int, str] = 'AUTO'):
+def handle_type_set(type: typing.Union[str, int] = 'AUTO'):
     ''' Set type of handles for selected control points
 
     :param type: Type, Spline type
-    :type type: typing.Union[int, str]
+    :type type: typing.Union[str, int]
     '''
 
     pass
@@ -122,11 +122,11 @@ def hide_view_set(unselected: bool = False):
     pass
 
 
-def layer_move(direction: typing.Union[int, str] = 'UP'):
+def layer_move(direction: typing.Union[str, int] = 'UP'):
     ''' Move the active layer up/down in the list
 
     :param direction: Direction, Direction to move the active layer
-    :type direction: typing.Union[int, str]
+    :type direction: typing.Union[str, int]
     '''
 
     pass
@@ -237,11 +237,11 @@ def select(extend: bool = False,
     pass
 
 
-def select_all(action: typing.Union[int, str] = 'TOGGLE'):
+def select_all(action: typing.Union[str, int] = 'TOGGLE'):
     ''' Change selection of all curve points
 
     :param action: Action, Selection action to execute * TOGGLE Toggle, Toggle selection for all elements. * SELECT Select, Select all elements. * DESELECT Deselect, Deselect all elements. * INVERT Invert, Invert selection of all elements.
-    :type action: typing.Union[int, str]
+    :type action: typing.Union[str, int]
     '''
 
     pass
@@ -291,15 +291,14 @@ def select_circle(x: int = 0,
     pass
 
 
-def select_lasso(path: typing.Union[
-        typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.
-        List['bpy.types.OperatorMousePath'], 'bpy_prop_collection'] = None,
+def select_lasso(path: typing.Union[typing.List['bpy.types.OperatorMousePath'],
+                                    'bpy_prop_collection'] = None,
                  deselect: bool = False,
                  extend: bool = True):
     ''' Select curve points using lasso selection
 
     :param path: Path
-    :type path: typing.Union[typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
+    :type path: typing.Union[typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
     :param deselect: Deselect, Deselect rather than select items
     :type deselect: bool
     :param extend: Extend, Extend selection instead of deselecting everything first
