@@ -735,14 +735,14 @@ def inset(use_boundary: bool = True,
 
 
 def intersect(mode: typing.Union[str, int] = 'SELECT_UNSELECT',
-              use_separate: bool = True,
+              separate_mode: typing.Union[str, int] = 'CUT',
               threshold: float = 1e-06):
     ''' Cut an intersection into faces
 
     :param mode: Source * SELECT Self Intersect, Self intersect selected faces. * SELECT_UNSELECT Selected/Unselected, Intersect selected with unselected faces.
     :type mode: typing.Union[str, int]
-    :param use_separate: Separate
-    :type use_separate: bool
+    :param separate_mode: Separate Mode * ALL All, Separate all geometry from intersections. * CUT Cut, Cut into geometry keeping each side separate (Selected/Unselected only). * NONE Merge, Merge all geometry from the intersection.
+    :type separate_mode: typing.Union[str, int]
     :param threshold: Merge threshold
     :type threshold: float
     '''
@@ -1239,6 +1239,7 @@ def primitive_ico_sphere_add(
 
 def primitive_monkey_add(
         radius: float = 1.0,
+        calc_uvs: bool = False,
         view_align: bool = False,
         enter_editmode: bool = False,
         location: typing.List[float] = (0.0, 0.0, 0.0),
@@ -1251,6 +1252,8 @@ def primitive_monkey_add(
 
     :param radius: Radius
     :type radius: float
+    :param calc_uvs: Generate UVs, Generate a default UV map
+    :type calc_uvs: bool
     :param view_align: Align to View, Align the new object to the view
     :type view_align: bool
     :param enter_editmode: Enter Editmode, Enter editmode when adding this object
@@ -1300,29 +1303,30 @@ def primitive_plane_add(
 
 def primitive_torus_add(
         rotation: typing.List[float] = (0.0, 0.0, 0.0),
+        view_align: bool = False,
         layers: typing.List[bool] = (False, False, False, False, False, False,
                                      False, False, False, False, False, False,
                                      False, False, False, False, False, False,
                                      False, False),
         location: typing.List[float] = (0.0, 0.0, 0.0),
-        view_align: bool = False,
         major_segments: int = 48,
         minor_segments: int = 12,
         mode: typing.Union[str, int] = 'MAJOR_MINOR',
         major_radius: float = 1.0,
         minor_radius: float = 0.25,
         abso_major_rad: float = 1.25,
-        abso_minor_rad: float = 0.75):
+        abso_minor_rad: float = 0.75,
+        generate_uvs: bool = False):
     ''' Add a torus mesh
 
     :param rotation: Rotation
     :type rotation: typing.List[float]
+    :param view_align: Align to View
+    :type view_align: bool
     :param layers: Layers
     :type layers: typing.List[bool]
     :param location: Location
     :type location: typing.List[float]
-    :param view_align: Align to View
-    :type view_align: bool
     :param major_segments: Major Segments, Number of segments for the main ring of the torus
     :type major_segments: int
     :param minor_segments: Minor Segments, Number of segments for the minor ring of the torus
@@ -1337,6 +1341,8 @@ def primitive_torus_add(
     :type abso_major_rad: float
     :param abso_minor_rad: Interior Radius, Total Interior Radius of the torus
     :type abso_minor_rad: float
+    :param generate_uvs: Generate UVs, Generate a default UV map
+    :type generate_uvs: bool
     '''
 
     pass
@@ -1426,6 +1432,7 @@ def rip(mirror: bool = False,
         proportional_edit_falloff: typing.Union[str, int] = 'SMOOTH',
         proportional_size: float = 1.0,
         release_confirm: bool = False,
+        use_accurate: bool = False,
         use_fill: bool = False):
     ''' Disconnect vertex or edges from connected geometry
 
@@ -1439,6 +1446,8 @@ def rip(mirror: bool = False,
     :type proportional_size: float
     :param release_confirm: Confirm on Release, Always confirm operation when releasing button
     :type release_confirm: bool
+    :param use_accurate: Accurate, Use accurate transformation
+    :type use_accurate: bool
     :param use_fill: Fill, Fill the ripped region
     :type use_fill: bool
     '''
@@ -1450,7 +1459,8 @@ def rip_edge(mirror: bool = False,
              proportional: typing.Union[str, int] = 'DISABLED',
              proportional_edit_falloff: typing.Union[str, int] = 'SMOOTH',
              proportional_size: float = 1.0,
-             release_confirm: bool = False):
+             release_confirm: bool = False,
+             use_accurate: bool = False):
     ''' Extend vertices along the edge closest to the cursor
 
     :param mirror: Mirror Editing
@@ -1463,6 +1473,8 @@ def rip_edge(mirror: bool = False,
     :type proportional_size: float
     :param release_confirm: Confirm on Release, Always confirm operation when releasing button
     :type release_confirm: bool
+    :param use_accurate: Accurate, Use accurate transformation
+    :type use_accurate: bool
     '''
 
     pass
@@ -1579,7 +1591,7 @@ def select_less(use_face_step: bool = True):
 
 def select_linked(
         delimit: typing.Union[typing.Set[str], typing.Set[int]] = {'SEAM'}):
-    ''' Select all vertices linked to the active mesh
+    ''' Select all vertices connected to the current selection
 
     :param delimit: Delimit, Delimit selected region * NORMAL Normal, Delimit by face directions. * MATERIAL Material, Delimit by face material. * SEAM Seam, Delimit by edge seams. * SHARP Sharp, Delimit by sharp edges. * UV UVs, Delimit by UV coordinates.
     :type delimit: typing.Union[typing.Set[str], typing.Set[int]]
@@ -1657,7 +1669,7 @@ def select_more(use_face_step: bool = True):
 
 
 def select_next_item():
-    ''' Select the next element (using selection order) :file: startup/bl_operators/mesh.py <https://developer.blender.org/diffusion/B/browse/master/release/scripts/ /startup/bl_operators/mesh.py> _:163
+    ''' Select the next element (using selection order)
 
     '''
 
@@ -1704,7 +1716,7 @@ def select_nth(nth: int = 2, skip: int = 1, offset: int = 0):
 
 
 def select_prev_item():
-    ''' Select the next element (using selection order) :file: startup/bl_operators/mesh.py <https://developer.blender.org/diffusion/B/browse/master/release/scripts/ /startup/bl_operators/mesh.py> _:188
+    ''' Select the previous element (using selection order)
 
     '''
 
@@ -1771,6 +1783,14 @@ def separate(type: typing.Union[str, int] = 'SELECTED'):
     pass
 
 
+def set_normals_from_faces():
+    ''' Set the custom vertex normals from the selected faces ones
+
+    '''
+
+    pass
+
+
 def shape_propagate_to_all():
     ''' Apply selected vertex locations to all other shape keys
 
@@ -1812,7 +1832,7 @@ def shortest_path_select(use_face_step: bool = False,
                          nth: int = 1,
                          skip: int = 1,
                          offset: int = 0):
-    ''' Selected vertex path between two vertices
+    ''' Selected shortest path between two vertices/edges/faces
 
     :param use_face_step: Face Stepping, Traverse connected faces (includes diagonals and edge-rings)
     :type use_face_step: bool
