@@ -4,18 +4,17 @@ import bpy.types
 
 
 def add_and_link_node(
-        settings: typing.
-        Union[typing.Dict[str, 'bpy.types.NodeSetting'], typing.
-              List['bpy.types.NodeSetting'], 'bpy_prop_collection'] = None,
         type: str = "",
+        settings: typing.Union[typing.List['bpy.types.NodeSetting'],
+                               'bpy_prop_collection'] = None,
         use_transform: bool = False,
         link_socket_index: int = 0):
     ''' Add a node to the active tree and link to an existing socket
 
-    :param settings: Settings, Settings to be applied on the newly created node
-    :type settings: typing.Union[typing.Dict[str, 'bpy.types.NodeSetting'], typing.List['bpy.types.NodeSetting'], 'bpy_prop_collection']
     :param type: Node Type, Node type
     :type type: str
+    :param settings: Settings, Settings to be applied on the newly created node
+    :type settings: typing.Union[typing.List['bpy.types.NodeSetting'], 'bpy_prop_collection']
     :param use_transform: Use Transform, Start transform operator after inserting the node
     :type use_transform: bool
     :param link_socket_index: Link Socket Index, Index of the socket to link
@@ -88,7 +87,7 @@ def add_file(filepath: str = "",
     :type display_type: typing.Union[str, int]
     :param sort_method: File sorting mode * FILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically. * FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type. * FILE_SORT_TIME Sort by time, Sort files by modification time. * FILE_SORT_SIZE Sort by size, Sort files by size.
     :type sort_method: typing.Union[str, int]
-    :param name: Name, Datablock name to assign
+    :param name: Name, Data-block name to assign
     :type name: str
     '''
 
@@ -98,25 +97,23 @@ def add_file(filepath: str = "",
 def add_mask(name: str = "Mask"):
     ''' Add a mask node to the current node editor
 
-    :param name: Name, Datablock name to assign
+    :param name: Name, Data-block name to assign
     :type name: str
     '''
 
     pass
 
 
-def add_node(
-        settings: typing.
-        Union[typing.Dict[str, 'bpy.types.NodeSetting'], typing.
-              List['bpy.types.NodeSetting'], 'bpy_prop_collection'] = None,
-        type: str = "",
-        use_transform: bool = False):
+def add_node(type: str = "",
+             settings: typing.Union[typing.List['bpy.types.NodeSetting'],
+                                    'bpy_prop_collection'] = None,
+             use_transform: bool = False):
     ''' Add a node to the active tree
 
-    :param settings: Settings, Settings to be applied on the newly created node
-    :type settings: typing.Union[typing.Dict[str, 'bpy.types.NodeSetting'], typing.List['bpy.types.NodeSetting'], 'bpy_prop_collection']
     :param type: Node Type, Node type
     :type type: str
+    :param settings: Settings, Settings to be applied on the newly created node
+    :type settings: typing.Union[typing.List['bpy.types.NodeSetting'], 'bpy_prop_collection']
     :param use_transform: Use Transform, Start transform operator after inserting the node
     :type use_transform: bool
     '''
@@ -124,14 +121,13 @@ def add_node(
     pass
 
 
-def add_reroute(path: typing.Union[
-        typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.
-        List['bpy.types.OperatorMousePath'], 'bpy_prop_collection'] = None,
+def add_reroute(path: typing.Union[typing.List['bpy.types.OperatorMousePath'],
+                                   'bpy_prop_collection'] = None,
                 cursor: int = 6):
     ''' Add a reroute node
 
     :param path: path
-    :type path: typing.Union[typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
+    :type path: typing.Union[typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
     :param cursor: Cursor
     :type cursor: int
     '''
@@ -139,19 +135,17 @@ def add_reroute(path: typing.Union[
     pass
 
 
-def add_search(
-        settings: typing.
-        Union[typing.Dict[str, 'bpy.types.NodeSetting'], typing.
-              List['bpy.types.NodeSetting'], 'bpy_prop_collection'] = None,
-        type: str = "",
-        use_transform: bool = False,
-        node_item: typing.Union[str, int] = ''):
+def add_search(type: str = "",
+               settings: typing.Union[typing.List['bpy.types.NodeSetting'],
+                                      'bpy_prop_collection'] = None,
+               use_transform: bool = False,
+               node_item: typing.Union[str, int] = ''):
     ''' Add a node to the active tree
 
-    :param settings: Settings, Settings to be applied on the newly created node
-    :type settings: typing.Union[typing.Dict[str, 'bpy.types.NodeSetting'], typing.List['bpy.types.NodeSetting'], 'bpy_prop_collection']
     :param type: Node Type, Node type
     :type type: str
+    :param settings: Settings, Settings to be applied on the newly created node
+    :type settings: typing.Union[typing.List['bpy.types.NodeSetting'], 'bpy_prop_collection']
     :param use_transform: Use Transform, Start transform operator after inserting the node
     :type use_transform: bool
     :param node_item: Node Type, Node type
@@ -228,7 +222,7 @@ def clipboard_paste():
 
 
 def collapse_hide_unused_toggle():
-    ''' Toggle collapsed nodes and hide unused sockets :file: startup/bl_operators/node.py <https://developer.blender.org/diffusion/B/browse/master/release/scripts/ /startup/bl_operators/node.py> _:262
+    ''' Toggle collapsed nodes and hide unused sockets
 
     '''
 
@@ -417,14 +411,13 @@ def link_viewer():
     pass
 
 
-def links_cut(path: typing.Union[
-        typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.
-        List['bpy.types.OperatorMousePath'], 'bpy_prop_collection'] = None,
+def links_cut(path: typing.Union[typing.List['bpy.types.OperatorMousePath'],
+                                 'bpy_prop_collection'] = None,
               cursor: int = 9):
     ''' Use the mouse to cut (remove) some links
 
     :param path: path
-    :type path: typing.Union[typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
+    :type path: typing.Union[typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
     :param cursor: Cursor
     :type cursor: int
     '''
@@ -680,15 +673,14 @@ def select_grouped(extend: bool = False,
     pass
 
 
-def select_lasso(path: typing.Union[
-        typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.
-        List['bpy.types.OperatorMousePath'], 'bpy_prop_collection'] = None,
+def select_lasso(path: typing.Union[typing.List['bpy.types.OperatorMousePath'],
+                                    'bpy_prop_collection'] = None,
                  deselect: bool = False,
                  extend: bool = True):
     ''' Select nodes using lasso selection
 
     :param path: Path
-    :type path: typing.Union[typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
+    :type path: typing.Union[typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
     :param deselect: Deselect, Deselect rather than select items
     :type deselect: bool
     :param extend: Extend, Extend selection instead of deselecting everything first
@@ -785,7 +777,7 @@ def translate_attach_remove_on_cancel(TRANSFORM_OT_translate=None,
 
 
 def tree_path_parent():
-    ''' Go to parent node tree :file: startup/bl_operators/node.py <https://developer.blender.org/diffusion/B/browse/master/release/scripts/ /startup/bl_operators/node.py> _:292
+    ''' Go to parent node tree
 
     '''
 
