@@ -23,7 +23,7 @@ def add_texture_paint_slot(type: typing.Union[str, int] = 'DIFFUSE_COLOR',
 
     :param type: Type, Merge method to use
     :type type: typing.Union[str, int]
-    :param name: Name, Image datablock name
+    :param name: Name, Image data-block name
     :type name: str
     :param width: Width, Image width
     :type width: int
@@ -179,14 +179,14 @@ def image_from_view(filepath: str = ""):
     pass
 
 
-def image_paint(stroke: typing.Union[
-        typing.Dict[str, 'bpy.types.OperatorStrokeElement'], typing.
-        List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection'] = None,
-                mode: typing.Union[str, int] = 'NORMAL'):
+def image_paint(
+        stroke: typing.Union[typing.List['bpy.types.OperatorStrokeElement'],
+                             'bpy_prop_collection'] = None,
+        mode: typing.Union[str, int] = 'NORMAL'):
     ''' Paint a stroke into the image
 
     :param stroke: Stroke
-    :type stroke: typing.Union[typing.Dict[str, 'bpy.types.OperatorStrokeElement'], typing.List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection']
+    :type stroke: typing.Union[typing.List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection']
     :param mode: Stroke Mode, Action taken when a paint stroke is made * NORMAL Normal, Apply brush normally. * INVERT Invert, Invert action of brush for duration of stroke. * SMOOTH Smooth, Switch brush to smooth mode for duration of stroke.
     :type mode: typing.Union[str, int]
     '''
@@ -207,15 +207,15 @@ def mask_flood_fill(mode: typing.Union[str, int] = 'VALUE',
     pass
 
 
-def mask_lasso_gesture(path: typing.Union[
-        typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.
-        List['bpy.types.OperatorMousePath'], 'bpy_prop_collection'] = None,
-                       mode: typing.Union[str, int] = 'VALUE',
-                       value: float = 1.0):
+def mask_lasso_gesture(
+        path: typing.Union[typing.List['bpy.types.OperatorMousePath'],
+                           'bpy_prop_collection'] = None,
+        mode: typing.Union[str, int] = 'VALUE',
+        value: float = 1.0):
     ''' Add mask within the lasso as you move the brush
 
     :param path: path
-    :type path: typing.Union[typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
+    :type path: typing.Union[typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
     :param mode: Mode * VALUE Value, Set mask to the level specified by the 'value' property. * VALUE_INVERSE Value Inverted, Set mask to the level specified by the inverted 'value' property. * INVERT Invert, Invert the mask.
     :type mode: typing.Union[str, int]
     :param value: Value, Mask level to use when mode is 'Value'; zero means no masking and one is fully masked
@@ -364,14 +364,14 @@ def vertex_color_smooth():
     pass
 
 
-def vertex_paint(stroke: typing.Union[
-        typing.Dict[str, 'bpy.types.OperatorStrokeElement'], typing.
-        List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection'] = None,
-                 mode: typing.Union[str, int] = 'NORMAL'):
+def vertex_paint(
+        stroke: typing.Union[typing.List['bpy.types.OperatorStrokeElement'],
+                             'bpy_prop_collection'] = None,
+        mode: typing.Union[str, int] = 'NORMAL'):
     ''' Paint a stroke in the active vertex color layer
 
     :param stroke: Stroke
-    :type stroke: typing.Union[typing.Dict[str, 'bpy.types.OperatorStrokeElement'], typing.List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection']
+    :type stroke: typing.Union[typing.List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection']
     :param mode: Stroke Mode, Action taken when a paint stroke is made * NORMAL Normal, Apply brush normally. * INVERT Invert, Invert action of brush for duration of stroke. * SMOOTH Smooth, Switch brush to smooth mode for duration of stroke.
     :type mode: typing.Union[str, int]
     '''
@@ -422,14 +422,14 @@ def weight_gradient(type: typing.Union[str, int] = 'LINEAR',
     pass
 
 
-def weight_paint(stroke: typing.Union[
-        typing.Dict[str, 'bpy.types.OperatorStrokeElement'], typing.
-        List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection'] = None,
-                 mode: typing.Union[str, int] = 'NORMAL'):
+def weight_paint(
+        stroke: typing.Union[typing.List['bpy.types.OperatorStrokeElement'],
+                             'bpy_prop_collection'] = None,
+        mode: typing.Union[str, int] = 'NORMAL'):
     ''' Paint a stroke in the current vertex group's weights
 
     :param stroke: Stroke
-    :type stroke: typing.Union[typing.Dict[str, 'bpy.types.OperatorStrokeElement'], typing.List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection']
+    :type stroke: typing.Union[typing.List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection']
     :param mode: Stroke Mode, Action taken when a paint stroke is made * NORMAL Normal, Apply brush normally. * INVERT Invert, Invert action of brush for duration of stroke. * SMOOTH Smooth, Switch brush to smooth mode for duration of stroke.
     :type mode: typing.Union[str, int]
     '''
