@@ -3,17 +3,17 @@ import typing
 import bpy.types
 
 
-def brush_stroke(stroke: typing.Union[
-        typing.Dict[str, 'bpy.types.OperatorStrokeElement'], typing.
-        List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection'] = None,
-                 mode: typing.Union[int, str] = 'NORMAL',
-                 ignore_background_click: bool = False):
+def brush_stroke(
+        stroke: typing.Union[typing.List['bpy.types.OperatorStrokeElement'],
+                             'bpy_prop_collection'] = None,
+        mode: typing.Union[str, int] = 'NORMAL',
+        ignore_background_click: bool = False):
     ''' Sculpt a stroke into the geometry
 
     :param stroke: Stroke
-    :type stroke: typing.Union[typing.Dict[str, 'bpy.types.OperatorStrokeElement'], typing.List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection']
+    :type stroke: typing.Union[typing.List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection']
     :param mode: Stroke Mode, Action taken when a paint stroke is made * NORMAL Normal, Apply brush normally. * INVERT Invert, Invert action of brush for duration of stroke. * SMOOTH Smooth, Switch brush to smooth mode for duration of stroke.
-    :type mode: typing.Union[int, str]
+    :type mode: typing.Union[str, int]
     :param ignore_background_click: Ignore Background Click, Clicks on the background do not start the stroke
     :type ignore_background_click: bool
     '''
@@ -87,11 +87,11 @@ def symmetrize():
     pass
 
 
-def uv_sculpt_stroke(mode: typing.Union[int, str] = 'NORMAL'):
+def uv_sculpt_stroke(mode: typing.Union[str, int] = 'NORMAL'):
     ''' Sculpt UVs using a brush
 
     :param mode: Mode, Stroke Mode * NORMAL Normal, Apply brush normally. * INVERT Invert, Invert action of brush for duration of stroke. * RELAX Relax, Switch brush to relax mode for duration of stroke.
-    :type mode: typing.Union[int, str]
+    :type mode: typing.Union[str, int]
     '''
 
     pass
