@@ -26,10 +26,8 @@ def change_effect_type(type: typing.Union[str, int] = 'CROSS'):
 def change_path(
         filepath: str = "",
         directory: str = "",
-        files: typing.
-        Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.
-              List['bpy.types.OperatorFileListElement'],
-              'bpy_prop_collection'] = None,
+        files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
+                            'bpy_prop_collection'] = None,
         filter_blender: bool = False,
         filter_backup: bool = False,
         filter_image: bool = False,
@@ -55,7 +53,7 @@ def change_path(
     :param directory: Directory, Directory of the file
     :type directory: str
     :param files: Files
-    :type files: typing.Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
+    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param filter_blender: Filter .blend files
     :type filter_blender: bool
     :param filter_backup: Filter .blend files
@@ -106,7 +104,7 @@ def copy():
 
 
 def crossfade_sounds():
-    ''' Do cross-fading volume animation of two selected sound strips :file: startup/bl_operators/sequencer.py <https://developer.blender.org/diffusion/B/browse/master/release/scripts/ /startup/bl_operators/sequencer.py> _:41
+    ''' Do cross-fading volume animation of two selected sound strips
 
     '''
 
@@ -140,7 +138,7 @@ def cut_multicam(camera: int = 1):
 
 
 def deinterlace_selected_movies():
-    ''' Deinterlace all selected movie sources :file: startup/bl_operators/sequencer.py <https://developer.blender.org/diffusion/B/browse/master/release/scripts/ /startup/bl_operators/sequencer.py> _:131
+    ''' Deinterlace all selected movie sources
 
     '''
 
@@ -207,7 +205,7 @@ def enable_proxies(proxy_25: bool = False,
                    proxy_50: bool = False,
                    proxy_75: bool = False,
                    proxy_100: bool = False,
-                   override: bool = False):
+                   overwrite: bool = False):
     ''' Enable selected proxies on all selected Movie strips
 
     :param proxy_25: 25%
@@ -218,8 +216,8 @@ def enable_proxies(proxy_25: bool = False,
     :type proxy_75: bool
     :param proxy_100: 100%
     :type proxy_100: bool
-    :param override: Override
-    :type override: bool
+    :param overwrite: Overwrite
+    :type overwrite: bool
     '''
 
     pass
@@ -308,10 +306,8 @@ def gap_remove(all: bool = False):
 
 def image_strip_add(
         directory: str = "",
-        files: typing.
-        Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.
-              List['bpy.types.OperatorFileListElement'],
-              'bpy_prop_collection'] = None,
+        files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
+                            'bpy_prop_collection'] = None,
         filter_blender: bool = False,
         filter_backup: bool = False,
         filter_image: bool = True,
@@ -342,7 +338,7 @@ def image_strip_add(
     :param directory: Directory, Directory of the file
     :type directory: str
     :param files: Files
-    :type files: typing.Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
+    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param filter_blender: Filter .blend files
     :type filter_blender: bool
     :param filter_backup: Filter .blend files
@@ -464,10 +460,8 @@ def meta_toggle():
 
 def movie_strip_add(
         filepath: str = "",
-        files: typing.
-        Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.
-              List['bpy.types.OperatorFileListElement'],
-              'bpy_prop_collection'] = None,
+        files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
+                            'bpy_prop_collection'] = None,
         filter_blender: bool = False,
         filter_backup: bool = False,
         filter_image: bool = False,
@@ -498,7 +492,7 @@ def movie_strip_add(
     :param filepath: File Path, Path to file
     :type filepath: str
     :param files: Files
-    :type files: typing.Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
+    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param filter_blender: Filter .blend files
     :type filter_blender: bool
     :param filter_backup: Filter .blend files
@@ -828,10 +822,8 @@ def snap(frame: int = 0):
 
 def sound_strip_add(
         filepath: str = "",
-        files: typing.
-        Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.
-              List['bpy.types.OperatorFileListElement'],
-              'bpy_prop_collection'] = None,
+        files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
+                            'bpy_prop_collection'] = None,
         filter_blender: bool = False,
         filter_backup: bool = False,
         filter_image: bool = False,
@@ -860,7 +852,7 @@ def sound_strip_add(
     :param filepath: File Path, Path to file
     :type filepath: str
     :param files: Files
-    :type files: typing.Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
+    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param filter_blender: Filter .blend files
     :type filter_blender: bool
     :param filter_backup: Filter .blend files
