@@ -59,7 +59,7 @@ def addon_install(overwrite: bool = True,
 
 
 def addon_refresh():
-    ''' Scan add-on directories for new modules :file: startup/bl_operators/wm.py <https://developer.blender.org/diffusion/B/browse/master/release/scripts/ /startup/bl_operators/wm.py> _:1912
+    ''' Scan add-on directories for new modules
 
     '''
 
@@ -104,8 +104,8 @@ def alembic_export(filepath: str = "",
                    filemode: int = 8,
                    display_type: typing.Union[str, int] = 'DEFAULT',
                    sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA',
-                   start: int = 1,
-                   end: int = 1,
+                   start: int = -2147483648,
+                   end: int = -2147483648,
                    xsamples: int = 1,
                    gsamples: int = 1,
                    sh_open: float = 0.0,
@@ -122,7 +122,14 @@ def alembic_export(filepath: str = "",
                    subdiv_schema: bool = False,
                    apply_subdiv: bool = False,
                    compression_type: typing.Union[str, int] = 'OGAWA',
-                   global_scale: float = 1.0):
+                   global_scale: float = 1.0,
+                   triangulate: bool = False,
+                   quad_method: typing.Union[str, int] = 'SHORTEST_DIAGONAL',
+                   ngon_method: typing.Union[str, int] = 'BEAUTY',
+                   export_hair: bool = True,
+                   export_particles: bool = True,
+                   as_background_job: bool = True,
+                   init_scene_frame_range: bool = False):
     ''' Export current scene in an Alembic archive
 
     :param filepath: File Path, Path to file
@@ -161,9 +168,9 @@ def alembic_export(filepath: str = "",
     :type display_type: typing.Union[str, int]
     :param sort_method: File sorting mode * FILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically. * FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type. * FILE_SORT_TIME Sort by time, Sort files by modification time. * FILE_SORT_SIZE Sort by size, Sort files by size.
     :type sort_method: typing.Union[str, int]
-    :param start: Start Frame, Start Frame
+    :param start: Start Frame, Start frame of the export, use the default value to take the start frame of the current scene
     :type start: int
-    :param end: End Frame, End Frame
+    :param end: End Frame, End frame of the export, use the default value to take the end frame of the current scene
     :type end: int
     :param xsamples: Transform Samples, Number of times per frame transformations are sampled
     :type xsamples: int
@@ -199,6 +206,19 @@ def alembic_export(filepath: str = "",
     :type compression_type: typing.Union[str, int]
     :param global_scale: Scale, Value by which to enlarge or shrink the objects with respect to the world's origin
     :type global_scale: float
+    :param triangulate: Triangulate, Export Polygons (Quads & NGons) as Triangles
+    :type triangulate: bool
+    :param quad_method: Quad Method, Method for splitting the quads into triangles * BEAUTY Beauty , Split the quads in nice triangles, slower method. * FIXED Fixed, Split the quads on the first and third vertices. * FIXED_ALTERNATE Fixed Alternate, Split the quads on the 2nd and 4th vertices. * SHORTEST_DIAGONAL Shortest Diagonal, Split the quads based on the distance between the vertices.
+    :type quad_method: typing.Union[str, int]
+    :param ngon_method: Polygon Method, Method for splitting the polygons into triangles * BEAUTY Beauty , Split the quads in nice triangles, slower method. * FIXED Fixed, Split the quads on the first and third vertices. * FIXED_ALTERNATE Fixed Alternate, Split the quads on the 2nd and 4th vertices. * SHORTEST_DIAGONAL Shortest Diagonal, Split the quads based on the distance between the vertices.
+    :type ngon_method: typing.Union[str, int]
+    :param export_hair: Export Hair, Exports hair particle systems as animated curves
+    :type export_hair: bool
+    :param export_particles: Export Particles, Exports non-hair particle systems
+    :type export_particles: bool
+    :param as_background_job: Run as Background Job, Enable this to run the import in the background, disable to block Blender while importing
+    :type as_background_job: bool
+    :type init_scene_frame_range: bool
     '''
 
     pass
@@ -225,7 +245,8 @@ def alembic_import(filepath: str = "",
                    scale: float = 1.0,
                    set_frame_range: bool = True,
                    validate_meshes: bool = False,
-                   is_sequence: bool = False):
+                   is_sequence: bool = False,
+                   as_background_job: bool = True):
     ''' Load an Alembic archive
 
     :param filepath: File Path, Path to file
@@ -272,6 +293,27 @@ def alembic_import(filepath: str = "",
     :type validate_meshes: bool
     :param is_sequence: Is Sequence, Set to true if the cache is split into separate files
     :type is_sequence: bool
+    :param as_background_job: Run as Background Job, Enable this to run the export in the background, disable to block Blender while exporting
+    :type as_background_job: bool
+    '''
+
+    pass
+
+
+def app_template_install(overwrite: bool = True,
+                         filepath: str = "",
+                         filter_folder: bool = True,
+                         filter_glob: str = "*.zip"):
+    ''' Install an application-template
+
+    :param overwrite: Overwrite, Remove existing template with the same ID
+    :type overwrite: bool
+    :param filepath: filepath
+    :type filepath: str
+    :param filter_folder: Filter folders
+    :type filter_folder: bool
+    :param filter_glob: filter_glob
+    :type filter_glob: str
     '''
 
     pass
@@ -288,42 +330,41 @@ def appconfig_activate(filepath: str = ""):
 
 
 def appconfig_default():
-    ''' Undocumented :file: startup/bl_operators/wm.py <https://developer.blender.org/diffusion/B/browse/master/release/scripts/ /startup/bl_operators/wm.py> _:1362
+    ''' Undocumented
 
     '''
 
     pass
 
 
-def append(filepath: str = "",
-           directory: str = "",
-           filename: str = "",
-           files: typing.
-           Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.
-                 List['bpy.types.OperatorFileListElement'],
-                 'bpy_prop_collection'] = None,
-           filter_blender: bool = True,
-           filter_backup: bool = False,
-           filter_image: bool = False,
-           filter_movie: bool = False,
-           filter_python: bool = False,
-           filter_font: bool = False,
-           filter_sound: bool = False,
-           filter_text: bool = False,
-           filter_btx: bool = False,
-           filter_collada: bool = False,
-           filter_alembic: bool = False,
-           filter_folder: bool = True,
-           filter_blenlib: bool = True,
-           filemode: int = 1,
-           display_type: typing.Union[str, int] = 'DEFAULT',
-           sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA',
-           link: bool = False,
-           autoselect: bool = True,
-           active_layer: bool = True,
-           instance_groups: bool = False,
-           set_fake: bool = False,
-           use_recursive: bool = True):
+def append(
+        filepath: str = "",
+        directory: str = "",
+        filename: str = "",
+        files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
+                            'bpy_prop_collection'] = None,
+        filter_blender: bool = True,
+        filter_backup: bool = False,
+        filter_image: bool = False,
+        filter_movie: bool = False,
+        filter_python: bool = False,
+        filter_font: bool = False,
+        filter_sound: bool = False,
+        filter_text: bool = False,
+        filter_btx: bool = False,
+        filter_collada: bool = False,
+        filter_alembic: bool = False,
+        filter_folder: bool = True,
+        filter_blenlib: bool = True,
+        filemode: int = 1,
+        display_type: typing.Union[str, int] = 'DEFAULT',
+        sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA',
+        link: bool = False,
+        autoselect: bool = True,
+        active_layer: bool = True,
+        instance_groups: bool = False,
+        set_fake: bool = False,
+        use_recursive: bool = True):
     ''' Append from a Library .blend file
 
     :param filepath: File Path, Path to file
@@ -333,7 +374,7 @@ def append(filepath: str = "",
     :param filename: File Name, Name of the file
     :type filename: str
     :param files: Files
-    :type files: typing.Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
+    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param filter_blender: Filter .blend files
     :type filter_blender: bool
     :param filter_backup: Filter .blend files
@@ -366,7 +407,7 @@ def append(filepath: str = "",
     :type display_type: typing.Union[str, int]
     :param sort_method: File sorting mode * FILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically. * FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type. * FILE_SORT_TIME Sort by time, Sort files by modification time. * FILE_SORT_SIZE Sort by size, Sort files by size.
     :type sort_method: typing.Union[str, int]
-    :param link: Link, Link the objects or datablocks rather than appending
+    :param link: Link, Link the objects or data-blocks rather than appending
     :type link: bool
     :param autoselect: Select, Select new objects
     :type autoselect: bool
@@ -384,7 +425,7 @@ def append(filepath: str = "",
 
 
 def blenderplayer_start():
-    ''' Launch the blender-player with the current blend-file :file: startup/bl_operators/wm.py <https://developer.blender.org/diffusion/B/browse/master/release/scripts/ /startup/bl_operators/wm.py> _:1462
+    ''' Launch the blender-player with the current blend-file
 
     '''
 
@@ -411,44 +452,47 @@ def call_menu_pie(name: str = ""):
     pass
 
 
-def collada_export(filepath: str = "",
-                   check_existing: bool = True,
-                   filter_blender: bool = False,
-                   filter_backup: bool = False,
-                   filter_image: bool = False,
-                   filter_movie: bool = False,
-                   filter_python: bool = False,
-                   filter_font: bool = False,
-                   filter_sound: bool = False,
-                   filter_text: bool = False,
-                   filter_btx: bool = False,
-                   filter_collada: bool = True,
-                   filter_alembic: bool = False,
-                   filter_folder: bool = True,
-                   filter_blenlib: bool = False,
-                   filemode: int = 8,
-                   display_type: typing.Union[str, int] = 'DEFAULT',
-                   sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA',
-                   apply_modifiers: bool = False,
-                   export_mesh_type: int = 0,
-                   export_mesh_type_selection: typing.Union[str, int] = 'view',
-                   selected: bool = False,
-                   include_children: bool = False,
-                   include_armatures: bool = False,
-                   include_shapekeys: bool = True,
-                   deform_bones_only: bool = False,
-                   active_uv_only: bool = False,
-                   include_uv_textures: bool = False,
-                   include_material_textures: bool = False,
-                   use_texture_copies: bool = True,
-                   triangulate: bool = True,
-                   use_object_instantiation: bool = True,
-                   use_blender_profile: bool = True,
-                   sort_by_name: bool = False,
-                   export_transformation_type: int = 0,
-                   export_transformation_type_selection: typing.
-                   Union[str, int] = 'matrix',
-                   open_sim: bool = False):
+def collada_export(
+        filepath: str = "",
+        check_existing: bool = True,
+        filter_blender: bool = False,
+        filter_backup: bool = False,
+        filter_image: bool = False,
+        filter_movie: bool = False,
+        filter_python: bool = False,
+        filter_font: bool = False,
+        filter_sound: bool = False,
+        filter_text: bool = False,
+        filter_btx: bool = False,
+        filter_collada: bool = True,
+        filter_alembic: bool = False,
+        filter_folder: bool = True,
+        filter_blenlib: bool = False,
+        filemode: int = 8,
+        display_type: typing.Union[str, int] = 'DEFAULT',
+        sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA',
+        apply_modifiers: bool = False,
+        export_mesh_type: int = 0,
+        export_mesh_type_selection: typing.Union[str, int] = 'view',
+        selected: bool = False,
+        include_children: bool = False,
+        include_armatures: bool = False,
+        include_shapekeys: bool = True,
+        deform_bones_only: bool = False,
+        active_uv_only: bool = False,
+        use_texture_copies: bool = True,
+        triangulate: bool = True,
+        use_object_instantiation: bool = True,
+        use_blender_profile: bool = True,
+        sort_by_name: bool = False,
+        export_transformation_type: int = 0,
+        export_transformation_type_selection: typing.
+        Union[str, int] = 'matrix',
+        export_texture_type: int = 0,
+        export_texture_type_selection: typing.Union[str, int] = 'mat',
+        open_sim: bool = False,
+        limit_precision: bool = False,
+        keep_bind_info: bool = False):
     ''' Save a Collada file
 
     :param filepath: File Path, Path to file
@@ -505,10 +549,6 @@ def collada_export(filepath: str = "",
     :type deform_bones_only: bool
     :param active_uv_only: Only Selected UV Map, Export only the selected UV Map
     :type active_uv_only: bool
-    :param include_uv_textures: Include UV Textures, Export textures assigned to the object UV Maps
-    :type include_uv_textures: bool
-    :param include_material_textures: Include Material Textures, Export textures assigned to the object Materials
-    :type include_material_textures: bool
     :param use_texture_copies: Copy, Copy textures to same folder where the .dae file is exported
     :type use_texture_copies: bool
     :param triangulate: Triangulate, Export Polygons (Quads & NGons) as Triangles
@@ -521,10 +561,18 @@ def collada_export(filepath: str = "",
     :type sort_by_name: bool
     :param export_transformation_type: Transform, Transformation type for translation, scale and rotation
     :type export_transformation_type: int
-    :param export_transformation_type_selection: Transform, Transformation type for translation, scale and rotation * matrix Matrix, Use <matrix> to specify transformations. * transrotloc TransRotLoc, Use <translate>, <rotate>, <scale> to specify transformations. * both Both, Use <matrix> AND <translate>, <rotate>, <scale> to specify transformations.
+    :param export_transformation_type_selection: Transform, Transformation type for translation, scale and rotation * matrix Matrix, Use <matrix> to specify transformations. * transrotloc TransRotLoc, Use <translate>, <rotate>, <scale> to specify transformations.
     :type export_transformation_type_selection: typing.Union[str, int]
+    :param export_texture_type: Texture Type, Type for exported Textures (UV or MAT)
+    :type export_texture_type: int
+    :param export_texture_type_selection: Texture Type, Type for exported Textures (UV or MAT) * mat Materials, Export Materials. * uv UV Textures, Export UV Textures (Face textures) as materials.
+    :type export_texture_type_selection: typing.Union[str, int]
     :param open_sim: Export to SL/OpenSim, Compatibility mode for SL, OpenSim and other compatible online worlds
     :type open_sim: bool
+    :param limit_precision: Limit Precision, Reduce the precision of the exported data to 6 digits
+    :type limit_precision: bool
+    :param keep_bind_info: Keep Bind Info, Store Bindpose information in custom bone properties for later use during Collada export
+    :type keep_bind_info: bool
     '''
 
     pass
@@ -551,7 +599,8 @@ def collada_import(filepath: str = "",
                    fix_orientation: bool = False,
                    find_chains: bool = False,
                    auto_connect: bool = False,
-                   min_chain_length: int = 0):
+                   min_chain_length: int = 0,
+                   keep_bind_info: bool = False):
     ''' Load a Collada file
 
     :param filepath: File Path, Path to file
@@ -598,6 +647,8 @@ def collada_import(filepath: str = "",
     :type auto_connect: bool
     :param min_chain_length: Minimum Chain Length, When searching Bone Chains disregard chains of length below this value
     :type min_chain_length: int
+    :param keep_bind_info: Keep Bind Info, Store Bindpose information in custom bone properties for later use during Collada export
+    :type keep_bind_info: bool
     '''
 
     pass
@@ -855,7 +906,7 @@ def context_toggle_enum(data_path: str = "",
 
 
 def copy_prev_settings():
-    ''' Copy settings from previous version :file: startup/bl_operators/wm.py <https://developer.blender.org/diffusion/B/browse/master/release/scripts/ /startup/bl_operators/wm.py> _:1428
+    ''' Copy settings from previous version
 
     '''
 
@@ -996,7 +1047,7 @@ def keyconfig_preset_add(name: str = "", remove_active: bool = False):
 
 
 def keyconfig_remove():
-    ''' Remove key config :file: startup/bl_operators/wm.py <https://developer.blender.org/diffusion/B/browse/master/release/scripts/ /startup/bl_operators/wm.py> _:1740
+    ''' Remove key config
 
     '''
 
@@ -1004,7 +1055,7 @@ def keyconfig_remove():
 
 
 def keyconfig_test():
-    ''' Test key-config for conflicts :file: startup/bl_operators/wm.py <https://developer.blender.org/diffusion/B/browse/master/release/scripts/ /startup/bl_operators/wm.py> _:1510
+    ''' Test key-config for conflicts
 
     '''
 
@@ -1012,7 +1063,7 @@ def keyconfig_test():
 
 
 def keyitem_add():
-    ''' Add key map item :file: startup/bl_operators/wm.py <https://developer.blender.org/diffusion/B/browse/master/release/scripts/ /startup/bl_operators/wm.py> _:1691
+    ''' Add key map item
 
     '''
 
@@ -1124,10 +1175,8 @@ def lib_relocate(
         filepath: str = "",
         directory: str = "",
         filename: str = "",
-        files: typing.
-        Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.
-              List['bpy.types.OperatorFileListElement'],
-              'bpy_prop_collection'] = None,
+        files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
+                            'bpy_prop_collection'] = None,
         filter_blender: bool = True,
         filter_backup: bool = False,
         filter_image: bool = False,
@@ -1156,7 +1205,7 @@ def lib_relocate(
     :param filename: File Name, Name of the file
     :type filename: str
     :param files: Files
-    :type files: typing.Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
+    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param filter_blender: Filter .blend files
     :type filter_blender: bool
     :param filter_backup: Filter .blend files
@@ -1199,10 +1248,8 @@ def lib_relocate(
 def link(filepath: str = "",
          directory: str = "",
          filename: str = "",
-         files: typing.
-         Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.
-               List['bpy.types.OperatorFileListElement'],
-               'bpy_prop_collection'] = None,
+         files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
+                             'bpy_prop_collection'] = None,
          filter_blender: bool = True,
          filter_backup: bool = False,
          filter_image: bool = False,
@@ -1233,7 +1280,7 @@ def link(filepath: str = "",
     :param filename: File Name, Name of the file
     :type filename: str
     :param files: Files
-    :type files: typing.Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
+    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param filter_blender: Filter .blend files
     :type filter_blender: bool
     :param filter_backup: Filter .blend files
@@ -1268,7 +1315,7 @@ def link(filepath: str = "",
     :type display_type: typing.Union[str, int]
     :param sort_method: File sorting mode * FILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically. * FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type. * FILE_SORT_TIME Sort by time, Sort files by modification time. * FILE_SORT_SIZE Sort by size, Sort files by size.
     :type sort_method: typing.Union[str, int]
-    :param link: Link, Link the objects or datablocks rather than appending
+    :param link: Link, Link the objects or data-blocks rather than appending
     :type link: bool
     :param autoselect: Select, Select new objects
     :type autoselect: bool
@@ -1354,7 +1401,7 @@ def open_mainfile(filepath: str = "",
 
 
 def operator_cheat_sheet():
-    ''' Undocumented :file: startup/bl_operators/wm.py <https://developer.blender.org/diffusion/B/browse/master/release/scripts/ /startup/bl_operators/wm.py> _:1751
+    ''' List all the Operators in a text-block, useful for scripting
 
     '''
 
@@ -1408,10 +1455,8 @@ def path_open(filepath: str = ""):
 
 
 def previews_batch_clear(
-        files: typing.
-        Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.
-              List['bpy.types.OperatorFileListElement'],
-              'bpy_prop_collection'] = None,
+        files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
+                            'bpy_prop_collection'] = None,
         directory: str = "",
         filter_blender: bool = True,
         filter_folder: bool = True,
@@ -1424,7 +1469,7 @@ def previews_batch_clear(
     ''' Clear selected .blend file's previews
 
     :param files: files
-    :type files: typing.Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
+    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param directory: directory
     :type directory: str
     :param filter_blender: filter_blender
@@ -1449,10 +1494,8 @@ def previews_batch_clear(
 
 
 def previews_batch_generate(
-        files: typing.
-        Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.
-              List['bpy.types.OperatorFileListElement'],
-              'bpy_prop_collection'] = None,
+        files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
+                            'bpy_prop_collection'] = None,
         directory: str = "",
         filter_blender: bool = True,
         filter_folder: bool = True,
@@ -1465,7 +1508,7 @@ def previews_batch_generate(
     ''' Generate selected .blend file's previews
 
     :param files: files
-    :type files: typing.Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
+    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param directory: directory
     :type directory: str
     :param filter_blender: filter_blender
@@ -1493,9 +1536,9 @@ def previews_clear(id_type: typing.Union[typing.Set[str], typing.Set[int]] = {
         'GROUP', 'IMAGE', 'LAMP', 'MATERIAL', 'OBJECT', 'SCENE', 'TEXTURE',
         'WORLD'
 }):
-    ''' Clear datablock previews (only for some types like objects, materials, textures, etc.)
+    ''' Clear data-block previews (only for some types like objects, materials, textures, etc.)
 
-    :param id_type: DataBlock Type, Which datablock previews to clear
+    :param id_type: Data-Block Type, Which data-block previews to clear
     :type id_type: typing.Union[typing.Set[str], typing.Set[int]]
     '''
 
@@ -1503,7 +1546,7 @@ def previews_clear(id_type: typing.Union[typing.Set[str], typing.Set[int]] = {
 
 
 def previews_ensure():
-    ''' Ensure datablock previews are available and up-to-date (to be saved in .blend file, only for some types like materials, textures, etc.)
+    ''' Ensure data-block previews are available and up-to-date (to be saved in .blend file, only for some types like materials, textures, etc.)
 
     '''
 
@@ -1624,9 +1667,13 @@ def radial_control(data_path_primary: str = "",
     pass
 
 
-def read_factory_settings():
+def read_factory_settings(app_template: str = "Template",
+                          use_empty: bool = False):
     ''' Load default file and user preferences
 
+    :type app_template: str
+    :param use_empty: Empty
+    :type use_empty: bool
     '''
 
     pass
@@ -1640,13 +1687,22 @@ def read_history():
     pass
 
 
-def read_homefile(filepath: str = "", load_ui: bool = True):
+def read_homefile(filepath: str = "",
+                  load_ui: bool = True,
+                  use_empty: bool = False,
+                  use_splash: bool = False,
+                  app_template: str = "Template"):
     ''' Open the default file (doesn't save the current file)
 
     :param filepath: File Path, Path to an alternative start-up file
     :type filepath: str
     :param load_ui: Load UI, Load user interface setup from the .blend file
     :type load_ui: bool
+    :param use_empty: Empty
+    :type use_empty: bool
+    :param use_splash: Splash
+    :type use_splash: bool
+    :type app_template: str
     '''
 
     pass
