@@ -1,7 +1,18 @@
 import sys
 import typing
-from . import previews
 from . import units
+from . import previews
+
+
+def app_template_paths(subdir: str = None):
+    ''' Returns valid application template paths.
+
+    :param subdir: Optional subdir.
+    :type subdir: str
+    :return: app template paths.
+    '''
+
+    pass
 
 
 def blend_paths(absolute: bool = False,
@@ -116,7 +127,7 @@ def refresh_script_paths():
 
 
 def register_class(cls):
-    ''' Register a subclass of a blender type in ( bpy.types.Panel , bpy.types.UIList , bpy.types.Menu , bpy.types.Header , bpy.types.Operator , bpy.types.KeyingSetInfo , bpy.types.RenderEngine ). If the class has a *register* class method it will be called before registration.
+    ''' Register a subclass of a blender type in ( bpy.types.Panel ,
 
     '''
 
@@ -139,6 +150,20 @@ def register_module(module, verbose=False):
     pass
 
 
+def register_submodule_factory(module_name: str,
+                               submodule_names: list) -> tuple:
+    ''' Utility function to create register and unregister functions which simply load submodules, calling their register & unregister functions.
+
+    :param module_name: The module name, typically __name__ .
+    :type module_name: str
+    :param submodule_names: List of submodule names to load and unload.
+    :type submodule_names: list
+    :return: register and unregister functions.
+    '''
+
+    pass
+
+
 def resource_path(type: str,
                   major: int = 'bpy.app.version[0]',
                   minor: str = 'bpy.app.version[1]') -> str:
@@ -174,7 +199,8 @@ def script_path_user():
 
 def script_paths(subdir: str = None,
                  user_pref: bool = True,
-                 check_all: bool = False) -> list:
+                 check_all: bool = False,
+                 use_user=True) -> list:
     ''' Returns a list of valid script paths.
 
     :param subdir: Optional subdir.
@@ -200,11 +226,11 @@ def smpte_from_frame(frame: int, fps=None, fps_base=None) -> str:
     pass
 
 
-def smpte_from_seconds(time: typing.Union[float, int], fps=None) -> str:
+def smpte_from_seconds(time: typing.Union[int, float], fps=None) -> str:
     ''' Returns an SMPTE formatted string from the *time*: HH:MM:SS:FF . If the *fps* is not given the current scene is used.
 
     :param time: time in seconds.
-    :type time: typing.Union[float, int]
+    :type time: typing.Union[int, float]
     :return: the frame string.
     '''
 
