@@ -1,10 +1,10 @@
 import sys
 import typing
+from . import interpolate
+from . import kdtree
 from . import geometry
 from . import noise
-from . import interpolate
 from . import bvhtree
-from . import kdtree
 
 
 class Color:
@@ -156,11 +156,11 @@ class Euler:
         '''
         pass
 
-    def rotate(self, other: typing.Union['Matrix', 'Euler', 'Quaternion']):
+    def rotate(self, other: typing.Union['Matrix', 'Quaternion', 'Euler']):
         ''' Rotates the euler by another mathutils value.
 
         :param other: rotation component of mathutils value
-        :type other: typing.Union['Matrix', 'Euler', 'Quaternion']
+        :type other: typing.Union['Matrix', 'Quaternion', 'Euler']
         '''
         pass
 
@@ -369,10 +369,10 @@ class Matrix:
         pass
 
     def decompose(self) -> 'Vector':
-        ''' Return the location, rotation and scale components of this matrix.
+        ''' Return the translation, rotation and scale components of this matrix.
 
         :rtype: 'Vector'
-        :return: loc, rot, scale triple.
+        :return: trans, rot, scale triple.
         '''
         pass
 
@@ -400,7 +400,7 @@ class Matrix:
     def invert(self, fallback: 'Matrix' = None):
         ''' Set the matrix to its inverse.
 
-        :param fallback: Set the matrix to this value when the inverse can't be calculated (instead of raising a :exc: ValueError exception).
+        :param fallback: Set the matrix to this value when the inverse cannot be calculated (instead of raising a :exc: ValueError exception).
         :type fallback: 'Matrix'
         '''
         pass
@@ -462,11 +462,11 @@ class Matrix:
         '''
         pass
 
-    def rotate(self, other: typing.Union['Matrix', 'Euler', 'Quaternion']):
+    def rotate(self, other: typing.Union['Matrix', 'Quaternion', 'Euler']):
         ''' Rotates the matrix by another mathutils value.
 
         :param other: rotation component of mathutils value
-        :type other: typing.Union['Matrix', 'Euler', 'Quaternion']
+        :type other: typing.Union['Matrix', 'Quaternion', 'Euler']
         '''
         pass
 
@@ -710,11 +710,11 @@ class Quaternion:
         '''
         pass
 
-    def rotate(self, other: typing.Union['Matrix', 'Euler', 'Quaternion']):
+    def rotate(self, other: typing.Union['Matrix', 'Quaternion', 'Euler']):
         ''' Rotates the quaternion by another mathutils value.
 
         :param other: rotation component of mathutils value
-        :type other: typing.Union['Matrix', 'Euler', 'Quaternion']
+        :type other: typing.Union['Matrix', 'Quaternion', 'Euler']
         '''
         pass
 
@@ -763,7 +763,7 @@ class Quaternion:
         pass
 
     def to_exponential_map(self) -> 'Vector':
-        ''' Return the exponential map representation of the quaternion. This representation consist of the rotation axis multiplied by the rotation angle. Such a representation is useful for interpolation between multiple orientations. To convert back to a quaternion, pass it to the Quaternion constructor.
+        ''' Return the exponential map representation of the quaternion. This representation consist of the rotation axis multiplied by the rotation angle. Such a representation is useful for interpolation between multiple orientations.
 
         :rtype: 'Vector'
         :return: exponential map.
@@ -2059,11 +2059,11 @@ class Vector:
         pass
 
     @staticmethod
-    def rotate(other: typing.Union['Matrix', 'Euler', 'Quaternion']):
+    def rotate(other: typing.Union['Matrix', 'Quaternion', 'Euler']):
         ''' Rotate the vector by a rotation value.
 
         :param other: rotation component of mathutils value
-        :type other: typing.Union['Matrix', 'Euler', 'Quaternion']
+        :type other: typing.Union['Matrix', 'Quaternion', 'Euler']
         '''
         pass
 
